@@ -476,8 +476,8 @@ display_bad_flags(struct minesdata *md, int no_x, int no_y)
 {
     int x, y, i;
     
-    for (y = 0; y < md->w; y++) {
-	for (x = 0; x < md->h; x++) {
+    for (y = 0; y < md->h; y++) {
+	for (x = 0; x < md->w; x++) {
 	    if (x != no_x || y != no_y) {
 		i = y * md->w + x;
 		if ((md->b[i] & PROTECTFLAG) &&
