@@ -16,8 +16,10 @@
 #define FONT_LINES 16
 
 
+#ifndef USEGETPIXEL
 static unsigned char *vga16mem = NULL;
 static int vga16width, vga16height;
+#endif
 static unsigned char *vga16workmem =  NULL;
 static char *font_bits;
 
@@ -37,18 +39,27 @@ vga16_init()
     if (mode->colors != 16) {
 	return -1;
     }
+#ifndef USEGETPIXEL
     if (vga16mem != NULL) {
 	free(vga16mem);
     }
     vga16mem = calloc(mode->width * mode->height / 2, sizeof(unsigned char));
+#endif
     vga16workmem = malloc(mode->width * sizeof(unsigned char));
     nelem = ((FONT_WIDTH + 7) / 8) * FONT_LINES * 256;
     font_bits = malloc(nelem * sizeof(char));
+#ifndef USEGETPIXEL
     if (vga16mem == NULL || vga16workmem == NULL || font_bits == NULL) {
 	return -1;
     }
+
     vga16width = mode->width;
     vga16height = mode->height;
+#else
+    if (vga16workmem == NULL || font_bits == NULL) {
+	return -1;
+    }
+#endif	
     
     f = fopen(VGA16FONT, "r");
     if (f == NULL) {
@@ -64,6 +75,7 @@ vga16_init()
 }
 
 
+#ifndef USEGETPIXEL
 void
 vga16_drawscansegment(unsigned char *colors, int x, int y, int length)
 {
@@ -95,12 +107,16 @@ vga16_drawscanline(int y, unsigned char *colors)
 {
     vga16_drawscansegment(colors, 0, y, vga16width);
 }
+#endif
 
 
 static void
 vga16_putchar(int x, int y, char c, int fg, int bg)
 {
-    int i, j, mask, vp, colour;
+    int i, j, mask, colour;
+#ifndef USEGETPIXEL
+    int vp;
+#endif
 
     y -= FONT_LINES - 1;
     for (i = FONT_LINES * c; i < FONT_LINES * (c + 1); i++) {
@@ -112,6 +128,7 @@ vga16_putchar(int x, int y, char c, int fg, int bg)
 		colour = bg;
 	    }
 	    
+#ifndef USEGETPIXEL
 	    vp = (y * vga16width + j) / 2;
 
 	    if (j & 1) {
@@ -127,6 +144,10 @@ vga16_putchar(int x, int y, char c, int fg, int bg)
 		    vga_drawpixel(j, y);
 		}
 	    }
+#else
+	    vga_setcolor(colour);
+	    vga_drawpixel(j, y);
+#endif	    
 
 	    mask = mask >> 1;
 	}
@@ -162,6 +183,7 @@ vga16_text(int x, int y, char *s, int fg, int bg)
 void
 vga16_setpixel(int color, int x, int y)
 {
+#ifndef USEGETPIXEL
     unsigned char *vp = &vga16mem[(y * vga16width + x) >> 1];
 
     if (x & 1) {
@@ -175,12 +197,14 @@ vga16_setpixel(int color, int x, int y)
 	}
 	*vp = (color << 4) | (*vp & 0x0f);
     }
+#endif
     
     vga_setcolor(color);
     vga_drawpixel(x, y);
 }
 
 
+#ifndef USEGETPIXEL
 int
 vga16_getpixel(int x, int y)
 {
@@ -192,6 +216,7 @@ vga16_getpixel(int x, int y)
 	return *vp >> 4;
     }
 }
+#endif
 
 
 /*
@@ -202,14 +227,18 @@ vga16_getpixel(int x, int y)
 void
 vga16_filledblock(int x0, int y0, int x1, int y1, int color)
 {
+    int x, y;
+#ifndef USEGETPIXEL
     unsigned char *vp;
-    int x, y, c;
+    int c;
+#endif
 
     for (x = 0; x <= x1 - x0; x++) {
 	vga16workmem[x] = color;
     }
 
     for (y = y0; y <= y1; y++) {
+#ifndef USEGETPIXEL
 	x = x0;
 	c = (color << 4) | color;
 	vp = &vga16mem[(y * vga16width + x) >> 1];
@@ -224,6 +253,7 @@ vga16_filledblock(int x0, int y0, int x1, int y1, int color)
 	if (x < x1) {
 	    *vp++ = (*vp & 0x0f) | (color << 4);
 	}
+#endif	
 	vga_drawscansegment(vga16workmem, x0, y, x1 - x0 + 1);
     }
 }
